==> xfmail-1.2.tar.gz: xfmail-1.2/ui/about.c <==
/*
 * Copyright(c) 1995,1996 by Gennady B. Sorokopud (gena@NetVision.net.il)
 *
 * This software can be freely redistributed and modified for 
 * non-commercial purposes as long as above copyright
 * message and this permission notice appear in all
 * copies of distributed source code and included as separate file
 * in binary distribution.
 *
 * Any commercial use of this software requires author's permission.
 *
 * This software is provided "as is" without expressed or implied
 * warranty of any kind.
 * Under no circumstances is the author responsible for the proper
 * functioning of this software, nor does the author assume any
 * responsibility for damages incurred with its use.
 *
 */

/* $Id: about.c,v 2.1 1997/12/14 15:27:25 gena Exp $
 */

#include <fmail.h>
#include <umail.h>
#include <choose_folder.h>
#include <gena.xpm>

static int ready = 0;
FD_About_Form *about_obj;

void
about(wait)
int wait;
{
char buf[255], compdate[64], *by;

 if ((wait == 2) && (ready == 1))
	goto end_about;

 if (ready == 1)
	return;

 about_obj = create_form_About_Form();
 if (wait == 1)
	fl_set_timer(about_obj->About_Timer, 3);
 strcpy(compdate, COMPILED);
 by = strstr(compdate, " by ");
 *by = '\0';
 by += 4;
 sprintf(buf, "Version:%s%s Patchlevel:%s OS:%s\nCompiled at: %s\nBy: %s", VERSION, DEBUGVERSION, PATCHLEVEL, XF_OS, compdate, by);
 fl_set_object_label(about_obj->Version_Text, buf);
 fl_set_pixmap_data(about_obj->Gena, gena);

 fl_set_form_minsize(about_obj->About_Form, 380, 290);
 fl_set_form_maxsize(about_obj->About_Form, 380, 290);
if (wait)
 fl_show_form(about_obj->About_Form, FL_PLACE_CENTER, FL_NOBORDER, NULL);
else
 fl_show_form(about_obj->About_Form, FL_PLACE_CENTER, FL_TRANSIENT, "About XFMail");

 if (wait == 1)
	return;

 ready = 1;
 fl_do_only_forms();

end_about: fl_hide_form(about_obj->About_Form);
 fl_free_form(about_obj->About_Form);
 fl_free(about_obj);
 about_obj = NULL;
 ready = 0;
 return;
}

void
About_Timer_Call(FL_OBJECT *obj, long param)
{
 if (ready != 1)
	return;

 about_obj = NULL;
 fl_hide_form(about_obj->About_Form);
 fl_free_form(about_obj->About_Form);
 fl_free(about_obj);
 ready = 0;
}

==> xfmail-1.3.tar.gz: xfmail-1.3/ui/about.c <==
/*
 * Copyright(c) 1995-1998 by Gennady B. Sorokopud (gena@NetVision.net.il)
 *
 * This software can be freely redistributed and modified for 
 * non-commercial purposes as long as above copyright
 * message and this permission notice appear in all
 * copies of distributed source code and included as separate file
 * in binary distribution.
 *
 * Any commercial use of this software requires author's permission.
 *
 * This software is provided "as is" without expressed or implied
 * warranty of any kind.
 * Under no circumstances is the author responsible for the proper
 * functioning of this software, nor does the author assume any
 * responsibility for damages incurred with its use.
 *
 */

/* $Id: about.c,v 2.3 1998/03/12 14:41:09 gena Exp $
 */

#include <fmail.h>
#include <umail.h>
#include <choose_folder.h>
#include <gena.xpm>

static int ready = 0;
FD_About_Form *about_obj;

void
about(wait)
int wait;
{
char buf[255], compdate[64], *by;

 if ((wait == 2) && (ready == 1))
	goto end_about;

 if (ready == 1)
	return;

 about_obj = create_form_About_Form();
 if (wait == 1)
	fl_set_timer(about_obj->About_Timer, 3);
 strcpy(compdate, COMPILED);
 by = strstr(compdate, " by ");
 *by = '\0';
 by += 4;
 snprintf(buf, sizeof(buf), "Version:%s%s Patchlevel:%s OS:%s\nCompiled at: %s\nBy: %s", VERSION, DEBUGVERSION, PATCHLEVEL, XF_OS, compdate, by);
 fl_set_object_label(about_obj->Version_Text, buf);
 fl_set_pixmap_data(about_obj->Gena, gena);

 fl_set_form_minsize(about_obj->About_Form, 380, 290);
 fl_set_form_maxsize(about_obj->About_Form, 380, 290);
if (wait)
 fl_show_form(about_obj->About_Form, FL_PLACE_CENTER, FL_NOBORDER, NULL);
else
 fl_show_form(about_obj->About_Form, FL_PLACE_CENTER, FL_TRANSIENT, "About XFMail");

 if (wait == 1)
	return;

 ready = 1;
 fl_do_only_forms();

end_about: fl_hide_form(about_obj->About_Form);
 fl_free_form(about_obj->About_Form);
 fl_free(about_obj);
 about_obj = NULL;
 ready = 0;
 return;
}

void
About_Timer_Call(FL_OBJECT *obj, long param)
{
 if (ready != 1)
	return;

 about_obj = NULL;
 fl_hide_form(about_obj->About_Form);
 fl_free_form(about_obj->About_Form);
 fl_free(about_obj);
 ready = 0;
}
